@@ -129,10 +129,13 @@ static inline void closeAndDrawWord(QPainter *p, Qt::LayoutDirection d,
     wordStart = wordEnd;
 }
 
-void Font::drawText( QPainter *p, int x, int y, QChar *str, int slen, int pos, int len,
+void Font::drawText( QPainter *p, int x, int y, const QChar *str, int slen, int pos, int len,
         int toAdd, Qt::LayoutDirection d, int from, int to, QColor bg, int uy, int h, int deco ) const
 {
-    if (!str) return;
+    if (!str || slen == 0) { // #188910
+        return;
+    }
+
     QString qstr = QString::fromRawData(str, slen);
 
     const QFontMetrics& fm = cfi->fm;
@@ -440,6 +443,8 @@ struct CachedFontFamilyKey // basically, FontDef minus the size (and for now SC)
 
     CachedFontFamilyKey() {}
 
+    // resolvedFamily is not actually what it claims to be, as it comes from css style.
+    // e.g. it could be something like "foo,Open Sans,Impact"
     CachedFontFamilyKey(const QString& resolvedFamily, int weight, bool italic) :
             family(resolvedFamily), weight(weight), italic(italic)
     {}
@@ -513,16 +518,18 @@ CachedFontFamily* Font::queryFamily(const QString& name, int weight, bool italic
 	QFont font(name);
 	font.setItalic(italic);
 	font.setWeight(weight);
-
+        // Use resolved family name to query font database
+        const QFontInfo fontInfo(font);
 	QFontDatabase db;
-	QString styleString = db.styleString(font);
+        const QString resolvedFamily = fontInfo.family();
+        const QString styleString = db.styleString(fontInfo);
 	f = new CachedFontFamily;
 	f->def       = key;
-	f->scaleable = db.isSmoothlyScalable(font.family(), styleString);
+	f->scaleable = db.isSmoothlyScalable(resolvedFamily, styleString);
 
 	if (!f->scaleable) {
 	    /* Cache size info */
-	    f->sizes = db.smoothSizes(font.family(), styleString);
+	    f->sizes = db.smoothSizes(resolvedFamily, styleString);
 	}
 
 	fontCache->insert(key, f);
@@ -737,4 +744,4 @@ float Font::floatWidth(QChar* str, int pos, int len) const
 
 }
 
-// kate: indent-width 4; replace-tabs off; tab-width 8; space-indent on; hl c++;
+// kate: indent-width 4; replace-tabs on; tab-width 8; space-indent on; hl c++;
